==> ripe-dbase-3.0.0.tar.gz: ripe-dbase-3.0/modules/sk/er_SK_errors.h <==
/***************************************
  $Revision: 1.3 $

  Error reporting (er) er_ER_errors.{m4,h} - definition of errors for the 
                              error reporting module

  Status: NOT REVUED, TESTED, 

  Design and implementation by: Marek Bukowy

  ******************/ /******************
  Copyright (c) 1999                              RIPE NCC
 
  All Rights Reserved
  
  Permission to use, copy, modify, and distribute this software and its
  documentation for any purpose and without fee is hereby granted,
  provided that the above copyright notice appear in all copies and that
  both that copyright notice and this permission notice appear in
  supporting documentation, and that the name of the author not be
  used in advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.
  
  THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
  AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/

/* 
NOTE:  modify the m4 file only, do not change the resulting .h !!!
*/

/* use m4 macros to keep stuff in sync */




     /******************************************/
     /* ***** DEFINE THE CURRENT FACILITY **** */
     /* * make sure no whitespaces are inside! */
     /* */               /* */
     /* ************************************** */
     /******************************************/

/* last thing: disable processing of commented text (this allows to comment
   out some macro entries. Alas, the #%$@&* designers screwed up, so now we
   have to manually disable messing with C preprocessor commands */





typedef enum {
  /*  fac  code    sev  descr
      
      current facility specified inside the line below as CFAC
   */

   LOW_SK_OK ,
   LOW_SK_BADHOST ,
   LOW_SK_CONNECT ,
   LOW_SK_BIND ,
   LOW_SK_SOCKET ,
   LOW_SK_ACERW ,  
   LOW_SK_ACERF ,
} SK_err_code_t;

/* paste the #define'd codes */
#define SK_OK  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_OK)
#define SK_BADHOST  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_BADHOST)
#define SK_CONNECT  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_CONNECT)
#define SK_BIND  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_BIND)
#define SK_SOCKET  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_SOCKET)
#define SK_ACERW  (ER_SEV_W + (FAC_SK<<16) + LOW_SK_ACERW)
#define SK_ACERF  (ER_SEV_F + (FAC_SK<<16) + LOW_SK_ACERF)
 

#ifdef ER_IMPL
er_list_t SK_mod_err[]={

  /* paste the ERDUP's */
    { ERDUP(SK_OK),"OK" },
  { ERDUP(SK_BADHOST),"unknown host" },
  { ERDUP(SK_CONNECT),"error while connecting to server" },
  { ERDUP(SK_BIND),"error while binding to socket" },
  { ERDUP(SK_SOCKET),"error while getting socket" },
  { ERDUP(SK_ACERW),"Transient accept error" },
  { ERDUP(SK_ACERF),"Too many accept errors in a row" },
 
  
  ER_LASTTXT
};
#endif /* ER_IMPL */

==> ripe-dbase-3.0.1.tar.gz: ripe-dbase-3.0.1/modules/sk/er_SK_errors.h <==
/***************************************
  $Revision: 1.4 $

  Error reporting (er) er_ER_errors.{m4,h} - definition of errors for the 
                              error reporting module

  Status: NOT REVUED, TESTED, 

  Design and implementation by: Marek Bukowy

  ******************/ /******************
  Copyright (c) 1999                              RIPE NCC
 
  All Rights Reserved
  
  Permission to use, copy, modify, and distribute this software and its
  documentation for any purpose and without fee is hereby granted,
  provided that the above copyright notice appear in all copies and that
  both that copyright notice and this permission notice appear in
  supporting documentation, and that the name of the author not be
  used in advertising or publicity pertaining to distribution of the
  software without specific, written prior permission.
  
  THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS; IN NO EVENT SHALL
  AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY
  DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  ***************************************/

/* 
NOTE:  modify the m4 file only, do not change the resulting .h !!!
*/

/* use m4 macros to keep stuff in sync */




     /******************************************/
     /* ***** DEFINE THE CURRENT FACILITY **** */
     /* * make sure no whitespaces are inside! */
     /* */               /* */
     /* ************************************** */
     /******************************************/

/* last thing: disable processing of commented text (this allows to comment
   out some macro entries. Alas, the #%$@&* designers screwed up, so now we
   have to manually disable messing with C preprocessor commands */





typedef enum {
  /*  fac  code    sev  descr
      
      current facility specified inside the line below as CFAC
   */

   LOW_SK_OK ,
   LOW_SK_BADHOST ,
   LOW_SK_CONNECT ,
   LOW_SK_BIND ,
   LOW_SK_SOCKET ,
   LOW_SK_ACERW ,  
   LOW_SK_ACERF ,
   LOW_SK_SELECT ,
} SK_err_code_t;

/* paste the #define'd codes */
#define SK_OK  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_OK)
#define SK_BADHOST  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_BADHOST)
#define SK_CONNECT  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_CONNECT)
#define SK_BIND  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_BIND)
#define SK_SOCKET  (ER_SEV_I + (FAC_SK<<16) + LOW_SK_SOCKET)
#define SK_ACERW  (ER_SEV_W + (FAC_SK<<16) + LOW_SK_ACERW)
#define SK_ACERF  (ER_SEV_F + (FAC_SK<<16) + LOW_SK_ACERF)
#define SK_SELECT  (ER_SEV_E + (FAC_SK<<16) + LOW_SK_SELECT)
 

#ifdef ER_IMPL
er_list_t SK_mod_err[]={

  /* paste the ERDUP's */
    { ERDUP(SK_OK),"OK" },
  { ERDUP(SK_BADHOST),"unknown host" },
  { ERDUP(SK_CONNECT),"error while connecting to server" },
  { ERDUP(SK_BIND),"error while binding to socket" },
  { ERDUP(SK_SOCKET),"error while getting socket" },
  { ERDUP(SK_ACERW),"Transient accept error" },
  { ERDUP(SK_ACERF),"Too many accept errors in a row" },
  { ERDUP(SK_SELECT),"error calling select on socket" },
 
  
  ER_LASTTXT
};
#endif /* ER_IMPL */
